==> jtech-1.0.6.tar.gz: jtech-1.0.6/jtech/utils/dir_constants.py <==
CQRS_PROTOCOLS = "protocols"
CQRS_SERVICES_QUERIES_IMPL = "services/queries/impl"
CQRS_SERVICES_QUERIES = "services/queries"
CQRS_SERVICES_COMMANDS_IMPL = "services/commands/impl"
CQRS_SERVICES_COMMANDS = "services/commands"
CQRS_AGGREGATE = "aggregate"
CQRS_AGGREGATE_IMPL = "aggregate/impl"
CQRS_CONTROLLERS_COMMANDS = "controllers/commands"
CQRS_CONTROLLERS_QUERIES = "controllers/queries"
CQRS_ENTITIES = "entities"
CQRS_REPOSITORIES = "repositories"
CQRS_COMMAND = "services/commands/command"
CQRS_QUERY = "services/queries/query"
CQRS_UTILS = "utils"
CQRS_VALIDATOR = "validators"
CQRS_INFRA = "infra"
CQRS_INFRA_EXCEPTIONS = "infra/exceptions"
CLEAN_DOMAINS = 'application/core/domains'
CLEAN_USECASE = 'application/core/usecases'
CLEAN_PORT_INPUT = 'application/ports/input'
CLEAN_PORT_OUTPUT = 'application/ports/output'
CLEAN_ADAPTERS_INPUT_CONTROLLERS = 'adapters/input/controllers'
CLEAN_ADAPTERS_INPUT_HANDLERS = 'adapters/input/handlers'
CLEAN_ADAPTERS_INPUT_PROTOCOLS = 'adapters/input/protocols'
CLEAN_ADAPTERS_OUTPUT_ENTITIES = 'adapters/output/repositories/entities'
CLEAN_ADAPTERS_OUTPUT_REPOSITORIES = 'adapters/output/repositories'
CLEAN_ADAPTERS = 'adapters/output'
CLEAN_CONFIG_INFRA_SWAGGER = 'config/infra/swagger'
CLEAN_CONFIG_INFRA_KAFKA = 'config/infra/kafka'
CLEAN_CONFIG_INFRA_REDIS = 'config/infra/redis'
CLEAN_CONFIG_INFRA_UTILS = 'config/infra/utils'
CLEAN_CONFIG_INFRA_EXCEPTIONS = 'config/infra/exceptions'
CLEAN_CONFIG_INFRA_HANDLERS = 'config/infra/handlers'
CLEAN_CONFIG_INFRA_LISTENERS = 'config/infra/listeners'
CLEAN_CONFIG_USECASES = 'config/usecases'
CLEAN_CONFIG_INFRA = 'config/infra'

==> jtech-1.0.9.tar.gz: jtech-1.0.9/jtech/utils/dir_constants.py <==
CQRS_PROTOCOLS = "protocols"
CQRS_SERVICES_QUERIES_IMPL = "services/queries/impl"
CQRS_SERVICES_QUERIES = "services/queries"
CQRS_SERVICES_COMMANDS_IMPL = "services/commands/impl"
CQRS_SERVICES_COMMANDS = "services/commands"
CQRS_AGGREGATE = "aggregate"
CQRS_AGGREGATE_IMPL = "aggregate/impl"
CQRS_CONTROLLERS_COMMANDS = "controllers/commands"
CQRS_CONTROLLERS_QUERIES = "controllers/queries"
CQRS_ENTITIES = "entities"
CQRS_REPOSITORIES = "repositories"
CQRS_COMMAND = "services/commands/command"
CQRS_QUERY = "services/queries/query"
CQRS_UTILS = "utils"
CQRS_VALIDATOR = "validators"
CQRS_INFRA = "infra"
CQRS_INFRA_EXCEPTIONS = "infra/exceptions"
CLEAN_DOMAINS = 'application/core/domains'
CLEAN_USECASE = 'application/core/usecases'
CLEAN_PORT_INPUT = 'application/ports/input'
CLEAN_PORT_OUTPUT = 'application/ports/output'
CLEAN_ADAPTERS_INPUT_CONTROLLERS = 'adapters/input/controllers'
CLEAN_ADAPTERS_INPUT_HANDLERS = 'adapters/input/handlers'
CLEAN_ADAPTERS_INPUT_PROTOCOLS = 'adapters/input/protocols'
CLEAN_ADAPTERS_OUTPUT_ENTITIES = 'adapters/output/repositories/entities'
CLEAN_ADAPTERS_OUTPUT_REPOSITORIES = 'adapters/output/repositories'
CLEAN_ADAPTERS_OUTPUT = 'adapters/output'
CLEAN_CONFIG_INFRA_SWAGGER = 'config/infra/swagger'
CLEAN_CONFIG_INFRA_KAFKA = 'config/infra/kafka'
CLEAN_CONFIG_INFRA_REDIS = 'config/infra/redis'
CLEAN_CONFIG_INFRA_UTILS = 'config/infra/utils'
CLEAN_CONFIG_INFRA_EXCEPTIONS = 'config/infra/exceptions'
CLEAN_CONFIG_INFRA_HANDLERS = 'config/infra/handlers'
CLEAN_CONFIG_INFRA_LISTENERS = 'config/infra/listeners'
CLEAN_CONFIG_USECASES = 'config/usecases'
CLEAN_CONFIG_INFRA = 'config/infra'
